package com.xinelu.manage.mapper.specialdiseasenode;

import com.xinelu.manage.domain.specialdiseasenode.SpecialDiseaseNode;
import com.xinelu.manage.vo.specialdiseasenode.PatientSpecialDiseaseNodeVo;
import com.xinelu.manage.vo.specialdiseasenode.RouteTaskAuditVo;
import com.xinelu.manage.vo.specialdiseasenode.SpecialDiseaseNodeAuditVo;
import com.xinelu.manage.vo.specialdiseasenode.SpecialDiseaseNodeVO;
import com.xinelu.manage.vo.specialdiseaseroute.SpecialDiseaseRouteVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 专病路径-管理节点信息Mapper接口
 *
 * @author xinelu
 * @date 2024-03-13
 */
public interface SpecialDiseaseNodeMapper {
    /**
     * 查询专病路径-管理节点信息
     *
     * @param id 专病路径-管理节点信息主键
     * @return 专病路径-管理节点信息
     */
    SpecialDiseaseNode selectSpecialDiseaseNodeById(Long id);

    /**
     * 查询专病路径-管理节点信息列表
     *
     * @param specialDiseaseNode 专病路径-管理节点信息
     * @return 专病路径-管理节点信息集合
     */
    List<SpecialDiseaseNode> selectSpecialDiseaseNodeList(SpecialDiseaseNode specialDiseaseNode);

	List<SpecialDiseaseNodeVO> selectSpeciaDiseaseNodeVoList(SpecialDiseaseNode specialDiseaseNode);
    /**
     * 新增专病路径-管理节点信息
     *
     * @param specialDiseaseNode 专病路径-管理节点信息
     * @return 结果
     */
    int insertSpecialDiseaseNode(SpecialDiseaseNode specialDiseaseNode);

    /**
     * 修改专病路径-管理节点信息
     *
     * @param specialDiseaseNode 专病路径-管理节点信息
     * @return 结果
     */
    int updateSpecialDiseaseNode(SpecialDiseaseNode specialDiseaseNode);

    /**
     * 删除专病路径-管理节点信息
     *
     * @param id 专病路径-管理节点信息主键
     * @return 结果
     */
    int deleteSpecialDiseaseNodeById(Long id);

    /**
     * 批量删除专病路径-管理节点信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSpecialDiseaseNodeByIds(Long[] ids);


    /**
     * 批量新增专病路径
     *
     * @param specialDiseaseNodeList 数据集合
     * @return int
     */
    int insertSpecialDiseaseNodeList(List<SpecialDiseaseNodeVO> specialDiseaseNodeList);

    /**
     * 删除专病路径-管理节点信息
     *
     * @param routeId 专病路径-管理节点信息主键
     * @return 结果
     */
    int deleteSpecialDiseaseNodeByRouteId(Long routeId);


    /**
     * 查询专病路径-管理节点信息
     *
     * @param specialDiseaseRouteId 专病路径-管理节点信息主键
     * @return 专病路径-管理节点信息
     */
    SpecialDiseaseRouteVO selectSpecialDiseaseByRouteId(Long specialDiseaseRouteId);

	/**
	 * 查询专病路径-管理节点信息
	 *
	 * @param specialDiseaseRouteId 专病路径-管理节点信息主键
	 * @return 专病路径-管理节点信息
	 */
	List<PatientSpecialDiseaseNodeVo> selectRouteNodeByRouteId(Long specialDiseaseRouteId);

	List<SpecialDiseaseNodeAuditVo> selectByRouteId(Long routeId);

    /**
     * 根据患者路径查询患者节点表
     *
     * @param specialDiseaseRouteId 患者路径
     * @return Long
     */
    List<Long> selectSpecialDiseaseRouteIds(Long specialDiseaseRouteId);

	/**
	 * 根据主路径id查询所有主路径节点及子路径节点
	 * @param parentRouteId 主路径id
	 * @return 主路径节点及子路径节点列表
	 */
	List<RouteTaskAuditVo> getByParentRouteId(Long parentRouteId);

    /**
     * 根据路径id查询节点信息
     *
     * @param specialDiseaseRouteIds
     * @return SpecialDiseaseNode
     */
    List<SpecialDiseaseNode> selectSpecialDiseaseNodes(@Param("specialDiseaseRouteIds") List<Long> specialDiseaseRouteIds);
}
